const knex = require('knex');
const logger = require('../utils/logger');

// Initialize knex with PostgreSQL configuration
const db = knex({
  client: 'pg',
  connection: process.env.DATABASE_URL,
  pool: {
    min: 2,
    max: 10
  },
  migrations: {
    tableName: 'knex_migrations',
    directory: '../migrations'
  },
  debug: process.env.NODE_ENV === 'development'
});

// Test database connection
const testConnection = async () => {
  try {
    await db.raw('SELECT 1');
    logger.info('Database connection established successfully');
    return true;
  } catch (error) {
    logger.error('Database connection failed:', error);
    return false;
  }
};

// Call the test function when this module is imported
testConnection();

module.exports = { db, testConnection };
