const nodeRegistry = require('../services/nodeRegistry');
const logger = require('../utils/logger');

/**
 * Get all available node types
 * @param {Object} req - Express request object
 * @param {Object} res - Express response object
 * @param {Function} next - Express next middleware function
 */
const getAllNodeTypes = async (req, res, next) => {
  try {
    const nodeTypes = nodeRegistry.getAllNodeTypes();
    
    res.status(200).json({
      count: nodeTypes.length,
      nodes: nodeTypes
    });
  } catch (error) {
    next(error);
  }
};

/**
 * Get a specific node type by type
 * @param {Object} req - Express request object
 * @param {Object} res - Express response object
 * @param {Function} next - Express next middleware function
 */
const getNodeType = async (req, res, next) => {
  try {
    const { type } = req.params;
    
    const nodeType = nodeRegistry.getNodeType(type);
    
    if (!nodeType) {
      return res.status(404).json({ 
        error: 'Not Found', 
        message: `Node type not found: ${type}` 
      });
    }
    
    res.status(200).json({
      node: nodeType.meta
    });
  } catch (error) {
    next(error);
  }
};

module.exports = {
  getAllNodeTypes,
  getNodeType
};
