const logger = require('../../utils/logger');

/**
 * Delay Node Runner
 * Pauses workflow execution for a specified time
 */
async function run(nodeConfig, inputData) {
  try {
    // Calculate delay in milliseconds
    let delayMs = nodeConfig.duration || 1000;
    
    // Convert based on unit
    switch (nodeConfig.unit) {
      case 'seconds':
        delayMs *= 1000;
        break;
      case 'minutes':
        delayMs *= 60 * 1000;
        break;
      case 'hours':
        delayMs *= 60 * 60 * 1000;
        break;
      default:
        // Default is milliseconds, no conversion needed
        break;
    }

    logger.debug('Delay node executing', { 
      duration: nodeConfig.duration,
      unit: nodeConfig.unit,
      delayMs
    });

    // Create a promise that resolves after the delay
    await new Promise(resolve => setTimeout(resolve, delayMs));

    // Pass through the input data to the output
    return {
      output: inputData.input || {}
    };
  } catch (error) {
    logger.error('Delay node error', { error: error.message });
    throw error;
  }
}

module.exports = { run };
