const logger = require('../../utils/logger');

/**
 * Logger Node Runner
 * Logs data to the console and workflow logs
 */
async function run(nodeConfig, inputData) {
  try {
    const level = nodeConfig.level || 'info';
    const message = nodeConfig.message || 'Logger node executed';
    const logInputData = nodeConfig.logInputData !== false; // Default to true
    
    // Prepare log data
    const logData = {
      message,
      timestamp: new Date().toISOString()
    };
    
    // Add input data if configured
    if (logInputData && inputData && inputData.input) {
      logData.data = inputData.input;
    }
    
    // Log with the appropriate level
    switch (level) {
      case 'debug':
        logger.debug(message, logData);
        break;
      case 'warn':
        logger.warn(message, logData);
        break;
      case 'error':
        logger.error(message, logData);
        break;
      case 'info':
      default:
        logger.info(message, logData);
        break;
    }
    
    // Pass through the input data to the output
    return {
      output: inputData.input || {}
    };
  } catch (error) {
    logger.error('Logger node error', { error: error.message });
    
    // Even if there's an error, try to pass through the input data
    return {
      output: inputData.input || {}
    };
  }
}

module.exports = { run };
