const logger = require('../../utils/logger');

/**
 * Webhook Node Runner
 * This node doesn't have a traditional "run" function since it's triggered by HTTP requests.
 * Instead, it provides functions to register and handle webhook endpoints.
 */

/**
 * Generate a unique webhook URL for a workflow node
 * @param {string} workflowId - The workflow ID
 * @param {string} nodeId - The node ID
 * @returns {string} The webhook path
 */
function generateWebhookPath(workflowId, nodeId) {
  return `/webhook/${workflowId}/${nodeId}`;
}

/**
 * Handle an incoming webhook request
 * @param {Object} req - Express request object
 * @param {Object} nodeConfig - Node configuration
 * @returns {Object} Data to pass to the next node
 */
function handleRequest(req, nodeConfig) {
  logger.debug('Webhook node triggered', { 
    path: req.path,
    method: req.method
  });

  // Prepare the output data
  const output = {
    method: req.method,
    path: req.path,
    query: req.query || {},
    params: req.params || {},
    headers: req.headers || {},
    body: req.body || {}
  };

  // Return the output data
  return {
    output
  };
}

module.exports = {
  generateWebhookPath,
  handleRequest
};
