import React from 'react';

const NodeTypeSelector = ({ nodeTypes }) => {
  // Handle drag start for node types
  const onDragStart = (event, nodeType) => {
    // Set data for the drag operation
    event.dataTransfer.setData('application/reactflow/type', 'customNode');
    event.dataTransfer.setData('application/reactflow/data', JSON.stringify(nodeType));
    event.dataTransfer.effectAllowed = 'move';
  };

  // Group node types by category
  const groupedNodeTypes = nodeTypes.reduce((acc, nodeType) => {
    const category = nodeType.category || 'Other';
    if (!acc[category]) {
      acc[category] = [];
    }
    acc[category].push(nodeType);
    return acc;
  }, {});

  // Get node color class based on type
  const getNodeColorClass = (type) => {
    switch (type) {
      case 'webhook':
        return 'border-blue-500 bg-blue-50';
      case 'http-request':
        return 'border-green-500 bg-green-50';
      case 'function':
        return 'border-purple-500 bg-purple-50';
      case 'delay':
        return 'border-amber-500 bg-amber-50';
      case 'email':
        return 'border-red-500 bg-red-50';
      case 'logger':
        return 'border-gray-500 bg-gray-50';
      default:
        return 'border-gray-300 bg-gray-50';
    }
  };

  return (
    <div className="p-4">
      <h3 className="text-lg font-medium text-gray-900 mb-4">Node Types</h3>
      
      <div className="space-y-6">
        {Object.entries(groupedNodeTypes).map(([category, nodes]) => (
          <div key={category} className="space-y-2">
            <h4 className="text-sm font-medium text-gray-700">{category}</h4>
            
            <div className="space-y-2">
              {nodes.map((nodeType) => (
                <div
                  key={nodeType.type}
                  className={`p-2 border-l-4 ${getNodeColorClass(nodeType.type)} rounded cursor-grab shadow-sm hover:shadow`}
                  draggable
                  onDragStart={(event) => onDragStart(event, nodeType)}
                >
                  <div className="text-sm font-medium">{nodeType.name}</div>
                  <div className="text-xs text-gray-500">{nodeType.description}</div>
                </div>
              ))}
            </div>
          </div>
        ))}
      </div>
      
      <div className="mt-6 pt-4 border-t border-gray-200">
        <p className="text-xs text-gray-500">
          Drag nodes to the canvas to build your workflow
        </p>
      </div>
    </div>
  );
};

export default NodeTypeSelector;
