import React, { useState } from 'react';
import { Tab } from '@headlessui/react';
import ExecutionHistory from '../execution/ExecutionHistory';
import CronScheduler from '../scheduling/CronScheduler';
import VersionHistory from './VersionHistory';
import WebhookManager from './WebhookManager';

function classNames(...classes) {
  return classes.filter(Boolean).join(' ');
}

const WorkflowEditorTabs = ({ 
  workflowId, 
  nodes, 
  currentVersion, 
  onRestoreVersion 
}) => {
  const [selectedTab, setSelectedTab] = useState(0);
  
  const tabs = [
    { name: 'Execution History', component: <ExecutionHistory workflowId={workflowId} /> },
    { name: 'Scheduling', component: <CronScheduler workflowId={workflowId} /> },
    { name: 'Version History', component: <VersionHistory 
      workflowId={workflowId} 
      currentVersion={currentVersion} 
      onRestoreVersion={onRestoreVersion} 
    /> },
    { name: 'Webhooks', component: <WebhookManager workflowId={workflowId} nodes={nodes} /> }
  ];

  return (
    <div className="w-full bg-white shadow">
      <Tab.Group selectedIndex={selectedTab} onChange={setSelectedTab}>
        <Tab.List className="flex space-x-1 border-b border-gray-200 px-4">
          {tabs.map((tab, index) => (
            <Tab
              key={index}
              className={({ selected }) =>
                classNames(
                  'py-4 px-4 text-sm font-medium leading-5 text-gray-700',
                  'focus:outline-none',
                  selected
                    ? 'border-b-2 border-primary-500 text-primary-600'
                    : 'text-gray-500 hover:text-gray-700 hover:border-gray-300'
                )
              }
            >
              {tab.name}
            </Tab>
          ))}
        </Tab.List>
        <Tab.Panels className="p-4">
          {tabs.map((tab, index) => (
            <Tab.Panel key={index}>
              {tab.component}
            </Tab.Panel>
          ))}
        </Tab.Panels>
      </Tab.Group>
    </div>
  );
};

export default WorkflowEditorTabs;
