import api from './api';

/**
 * Service for node-related API calls
 */
const nodeService = {
  /**
   * Get all available node types
   * @returns {Promise} Promise resolving to node types data
   */
  getNodeTypes: async () => {
    return api.get('/api/nodes');
  },

  /**
   * Get metadata for a specific node type
   * @param {string} type Node type identifier
   * @returns {Promise} Promise resolving to node metadata
   */
  getNodeMeta: async (type) => {
    return api.get(`/api/nodes/${type}/meta`);
  },

  /**
   * Get webhook URL for a specific workflow and node
   * @param {string} workflowId Workflow ID
   * @param {string} nodeId Node ID
   * @returns {Promise} Promise resolving to webhook URL data
   */
  getWebhookUrl: async (workflowId, nodeId) => {
    return api.get(`/api/workflows/${workflowId}/webhooks/${nodeId}`);
  },

  /**
   * Test a node configuration
   * @param {string} type Node type identifier
   * @param {Object} config Node configuration to test
   * @param {Object} input Test input data
   * @returns {Promise} Promise resolving to test results
   */
  testNodeConfig: async (type, config, input = {}) => {
    return api.post(`/api/nodes/${type}/test`, { config, input });
  }
};

export default nodeService;
