// Automation template definitions
const automationTemplates = [
  {
    id: 'tweet-to-sheets',
    name: 'New Tweet → Save to Google Sheets',
    description: 'Whenever a new tweet is posted on a Twitter account, log the tweet content, date, and link into a Google Sheet.',
    tags: ['twitter', 'google-sheets', 'social-media'],
    nodes: [
      {
        id: 'twitter-trigger',
        type: 'trigger',
        name: 'Twitter Trigger',
        position: { x: 100, y: 100 },
        config: {
          triggerType: 'twitter',
          accountName: '@username'
        }
      },
      {
        id: 'google-sheets',
        type: 'action',
        name: 'Google Sheets',
        position: { x: 400, y: 100 },
        config: {
          actionType: 'google-sheets',
          operation: 'append-row',
          spreadsheetId: '',
          sheetName: 'Tweets'
        }
      }
    ],
    connections: [
      {
        id: 'conn-1',
        source_node_id: 'twitter-trigger',
        target_node_id: 'google-sheets',
        source_handle: 'output',
        target_handle: 'input'
      }
    ]
  },
  {
    id: 'webhook-to-email',
    name: 'Webhook Receives Form Data → Send Email',
    description: 'When form data is sent to a webhook, format the message and email it to a predefined address.',
    tags: ['webhook', 'email', 'form'],
    nodes: [
      {
        id: 'webhook-trigger',
        type: 'trigger',
        name: 'Webhook',
        position: { x: 100, y: 100 },
        config: {
          triggerType: 'webhook',
          path: '/form-submission'
        }
      },
      {
        id: 'email-sender',
        type: 'action',
        name: 'Send Email',
        position: { x: 400, y: 100 },
        config: {
          actionType: 'email',
          to: 'recipient@example.com',
          subject: 'New Form Submission'
        }
      }
    ],
    connections: [
      {
        id: 'conn-1',
        source_node_id: 'webhook-trigger',
        target_node_id: 'email-sender',
        source_handle: 'output',
        target_handle: 'input'
      }
    ]
  },
  {
    id: 'github-to-discord',
    name: 'New GitHub Issue → Send Discord Notification',
    description: 'On creation of a new GitHub issue in a repository, post a message in a Discord channel.',
    tags: ['github', 'discord', 'developer'],
    nodes: [
      {
        id: 'github-trigger',
        type: 'trigger',
        name: 'GitHub Webhook',
        position: { x: 100, y: 100 },
        config: {
          triggerType: 'github',
          event: 'issues',
          action: 'opened'
        }
      },
      {
        id: 'discord-action',
        type: 'action',
        name: 'Discord Message',
        position: { x: 400, y: 100 },
        config: {
          actionType: 'discord',
          webhookUrl: '',
          channel: 'github-notifications'
        }
      }
    ],
    connections: [
      {
        id: 'conn-1',
        source_node_id: 'github-trigger',
        target_node_id: 'discord-action',
        source_handle: 'output',
        target_handle: 'input'
      }
    ]
  },
  {
    id: 'weather-forecast',
    name: 'Every Morning at 08:00 → Get Weather Forecast → Send Email',
    description: 'Trigger daily at 08:00 to fetch weather data from a weather API and email it to the user.',
    tags: ['schedule', 'weather', 'email'],
    nodes: [
      {
        id: 'schedule-trigger',
        type: 'trigger',
        name: 'Schedule',
        position: { x: 100, y: 100 },
        config: {
          triggerType: 'schedule',
          cronExpression: '0 8 * * *',
          timezone: 'UTC'
        }
      },
      {
        id: 'weather-api',
        type: 'action',
        name: 'Weather API',
        position: { x: 400, y: 100 },
        config: {
          actionType: 'http-request',
          method: 'GET',
          url: 'https://api.weatherapi.com/v1/forecast.json',
          params: {
            key: '{{API_KEY}}',
            q: 'London',
            days: 1
          }
        }
      },
      {
        id: 'email-sender',
        type: 'action',
        name: 'Send Email',
        position: { x: 700, y: 100 },
        config: {
          actionType: 'email',
          to: 'user@example.com',
          subject: 'Today\'s Weather Forecast'
        }
      }
    ],
    connections: [
      {
        id: 'conn-1',
        source_node_id: 'schedule-trigger',
        target_node_id: 'weather-api',
        source_handle: 'output',
        target_handle: 'input'
      },
      {
        id: 'conn-2',
        source_node_id: 'weather-api',
        target_node_id: 'email-sender',
        source_handle: 'output',
        target_handle: 'input'
      }
    ]
  },
  {
    id: 'notion-to-telegram',
    name: 'New Row in Notion Database → Send Telegram Message',
    description: 'When a new entry is added to a Notion table, send the content as a Telegram message.',
    tags: ['notion', 'telegram', 'productivity'],
    nodes: [
      {
        id: 'notion-trigger',
        type: 'trigger',
        name: 'Notion Database',
        position: { x: 100, y: 100 },
        config: {
          triggerType: 'notion',
          databaseId: ''
        }
      },
      {
        id: 'telegram-action',
        type: 'action',
        name: 'Telegram Message',
        position: { x: 400, y: 100 },
        config: {
          actionType: 'telegram',
          botToken: '{{BOT_TOKEN}}',
          chatId: ''
        }
      }
    ],
    connections: [
      {
        id: 'conn-1',
        source_node_id: 'notion-trigger',
        target_node_id: 'telegram-action',
        source_handle: 'output',
        target_handle: 'input'
      }
    ]
  },
  {
    id: 'youtube-rss-to-email',
    name: 'New YouTube Video Detected via RSS → Email to Subscribers',
    description: 'Monitor an RSS feed for new YouTube videos, and email the video details to all subscribers.',
    tags: ['youtube', 'rss', 'email', 'subscribers'],
    nodes: [
      {
        id: 'rss-trigger',
        type: 'trigger',
        name: 'RSS Feed',
        position: { x: 100, y: 100 },
        config: {
          triggerType: 'rss',
          feedUrl: 'https://www.youtube.com/feeds/videos.xml?channel_id=CHANNEL_ID',
          checkInterval: 3600 // Check every hour
        }
      },
      {
        id: 'get-subscribers',
        type: 'action',
        name: 'Get Subscribers',
        position: { x: 400, y: 100 },
        config: {
          actionType: 'database',
          operation: 'query',
          query: 'SELECT email FROM subscribers WHERE active = true'
        }
      },
      {
        id: 'email-sender',
        type: 'action',
        name: 'Send Email',
        position: { x: 700, y: 100 },
        config: {
          actionType: 'email',
          subject: 'New Video: {{title}}',
          body: 'Check out this new video: {{link}}'
        }
      }
    ],
    connections: [
      {
        id: 'conn-1',
        source_node_id: 'rss-trigger',
        target_node_id: 'get-subscribers',
        source_handle: 'output',
        target_handle: 'input'
      },
      {
        id: 'conn-2',
        source_node_id: 'get-subscribers',
        target_node_id: 'email-sender',
        source_handle: 'output',
        target_handle: 'input'
      }
    ]
  },
  {
    id: 'chatgpt-to-pdf',
    name: 'Send Message to ChatGPT → Convert Reply to PDF → Send Email',
    description: 'Accept a message via webhook, get a ChatGPT response, turn it into a PDF, and email it back.',
    tags: ['chatgpt', 'pdf', 'email', 'ai'],
    nodes: [
      {
        id: 'webhook-trigger',
        type: 'trigger',
        name: 'Webhook',
        position: { x: 100, y: 100 },
        config: {
          triggerType: 'webhook',
          path: '/chatgpt-request'
        }
      },
      {
        id: 'chatgpt-action',
        type: 'action',
        name: 'ChatGPT API',
        position: { x: 400, y: 100 },
        config: {
          actionType: 'openai',
          model: 'gpt-4',
          prompt: '{{message}}',
          temperature: 0.7
        }
      },
      {
        id: 'pdf-converter',
        type: 'action',
        name: 'Convert to PDF',
        position: { x: 700, y: 100 },
        config: {
          actionType: 'pdf-generator',
          title: 'ChatGPT Response',
          content: '{{response}}'
        }
      },
      {
        id: 'email-sender',
        type: 'action',
        name: 'Send Email',
        position: { x: 1000, y: 100 },
        config: {
          actionType: 'email',
          to: '{{email}}',
          subject: 'Your ChatGPT Response',
          attachments: ['{{pdf_file}}']
        }
      }
    ],
    connections: [
      {
        id: 'conn-1',
        source_node_id: 'webhook-trigger',
        target_node_id: 'chatgpt-action',
        source_handle: 'output',
        target_handle: 'input'
      },
      {
        id: 'conn-2',
        source_node_id: 'chatgpt-action',
        target_node_id: 'pdf-converter',
        source_handle: 'output',
        target_handle: 'input'
      },
      {
        id: 'conn-3',
        source_node_id: 'pdf-converter',
        target_node_id: 'email-sender',
        source_handle: 'output',
        target_handle: 'input'
      }
    ]
  },
  {
    id: 'sheets-to-whatsapp',
    name: 'New Google Sheet Row → Send WhatsApp Message',
    description: 'When a new row is added to a Google Sheet (e.g., new order), send a WhatsApp message to the customer.',
    tags: ['google-sheets', 'whatsapp', 'notification'],
    nodes: [
      {
        id: 'sheets-trigger',
        type: 'trigger',
        name: 'Google Sheets',
        position: { x: 100, y: 100 },
        config: {
          triggerType: 'google-sheets',
          spreadsheetId: '',
          sheetName: 'Orders'
        }
      },
      {
        id: 'whatsapp-action',
        type: 'action',
        name: 'WhatsApp Message',
        position: { x: 400, y: 100 },
        config: {
          actionType: 'whatsapp',
          to: '{{phone}}',
          message: 'Hello {{name}}, your order #{{order_id}} has been received!'
        }
      }
    ],
    connections: [
      {
        id: 'conn-1',
        source_node_id: 'sheets-trigger',
        target_node_id: 'whatsapp-action',
        source_handle: 'output',
        target_handle: 'input'
      }
    ]
  },
  {
    id: 'file-virus-scan',
    name: 'Receive File via Webhook → Scan with VirusTotal → Email Report',
    description: 'Upload a file through a webhook, scan it using the VirusTotal API, and send the scan report via email.',
    tags: ['security', 'file-upload', 'virus-scan'],
    nodes: [
      {
        id: 'webhook-trigger',
        type: 'trigger',
        name: 'Webhook',
        position: { x: 100, y: 100 },
        config: {
          triggerType: 'webhook',
          path: '/file-upload',
          acceptFiles: true
        }
      },
      {
        id: 'virustotal-action',
        type: 'action',
        name: 'VirusTotal Scan',
        position: { x: 400, y: 100 },
        config: {
          actionType: 'virustotal',
          apiKey: '{{API_KEY}}'
        }
      },
      {
        id: 'email-sender',
        type: 'action',
        name: 'Send Email',
        position: { x: 700, y: 100 },
        config: {
          actionType: 'email',
          to: '{{email}}',
          subject: 'File Scan Results',
          body: 'Scan results for {{filename}}: {{scan_results}}'
        }
      }
    ],
    connections: [
      {
        id: 'conn-1',
        source_node_id: 'webhook-trigger',
        target_node_id: 'virustotal-action',
        source_handle: 'output',
        target_handle: 'input'
      },
      {
        id: 'conn-2',
        source_node_id: 'virustotal-action',
        target_node_id: 'email-sender',
        source_handle: 'output',
        target_handle: 'input'
      }
    ]
  },
  {
    id: 'website-monitor',
    name: 'Check Website Every 10 Minutes → If Changed → Send Telegram Alert',
    description: 'Monitor a web page (e.g., product page) for changes. If the content differs, send a Telegram notification.',
    tags: ['monitoring', 'website', 'telegram'],
    nodes: [
      {
        id: 'schedule-trigger',
        type: 'trigger',
        name: 'Schedule',
        position: { x: 100, y: 100 },
        config: {
          triggerType: 'schedule',
          cronExpression: '*/10 * * * *', // Every 10 minutes
          timezone: 'UTC'
        }
      },
      {
        id: 'http-request',
        type: 'action',
        name: 'HTTP Request',
        position: { x: 400, y: 100 },
        config: {
          actionType: 'http-request',
          method: 'GET',
          url: 'https://example.com/product-page'
        }
      },
      {
        id: 'content-diff',
        type: 'logic',
        name: 'Check for Changes',
        position: { x: 700, y: 100 },
        config: {
          logicType: 'content-diff',
          selector: '.product-price',
          storageKey: 'last-product-price'
        }
      },
      {
        id: 'telegram-action',
        type: 'action',
        name: 'Telegram Alert',
        position: { x: 1000, y: 100 },
        config: {
          actionType: 'telegram',
          botToken: '{{BOT_TOKEN}}',
          chatId: '',
          message: 'Website content has changed! Check it out: https://example.com/product-page'
        }
      }
    ],
    connections: [
      {
        id: 'conn-1',
        source_node_id: 'schedule-trigger',
        target_node_id: 'http-request',
        source_handle: 'output',
        target_handle: 'input'
      },
      {
        id: 'conn-2',
        source_node_id: 'http-request',
        target_node_id: 'content-diff',
        source_handle: 'output',
        target_handle: 'input'
      },
      {
        id: 'conn-3',
        source_node_id: 'content-diff',
        target_node_id: 'telegram-action',
        source_handle: 'changed',
        target_handle: 'input'
      }
    ]
  }
];

export default automationTemplates;
