import React from 'react';
import ReactDOM from 'react-dom';
import ExecutionResults from './components/execution/ExecutionResults';
import ExecutionHistory from './components/execution/ExecutionHistory';
import CronScheduler from './components/scheduling/CronScheduler';
import VersionHistory from './components/workflow/VersionHistory';
import WebhookManager from './components/workflow/WebhookManager';
import NodeTester from './components/workflow/NodeTester';
import WorkflowEditorTabs from './components/workflow/WorkflowEditorTabs';
import WorkflowEditorActions from './components/workflow/WorkflowEditorActions';
import Modal from './components/common/Modal';
import './index.css';

// Mock data for testing
const mockWorkflowId = '123';
const mockExecutionId = '456';
const mockNodes = [
  {
    id: 'node1',
    type: 'webhook',
    data: { label: 'Webhook Node' }
  },
  {
    id: 'node2',
    type: 'http-request',
    data: { label: 'HTTP Request' }
  }
];
const mockSelectedNode = {
  id: 'node1',
  type: 'webhook',
  data: { 
    label: 'Webhook Node',
    config: { path: '/webhook/test' }
  }
};

// Test component that renders all our components
const TestComponents = () => {
  const [showModal, setShowModal] = React.useState(false);
  const [activeComponent, setActiveComponent] = React.useState(null);
  
  const renderComponent = (component) => {
    setActiveComponent(component);
    setShowModal(true);
  };
  
  return (
    <div className="p-8">
      <h1 className="text-3xl font-bold mb-8">FlowForge Component Testing</h1>
      
      <div className="grid grid-cols-2 gap-4 mb-8">
        <button 
          onClick={() => renderComponent('executionResults')}
          className="p-4 bg-blue-500 text-white rounded hover:bg-blue-600"
        >
          Test Execution Results
        </button>
        
        <button 
          onClick={() => renderComponent('executionHistory')}
          className="p-4 bg-green-500 text-white rounded hover:bg-green-600"
        >
          Test Execution History
        </button>
        
        <button 
          onClick={() => renderComponent('cronScheduler')}
          className="p-4 bg-purple-500 text-white rounded hover:bg-purple-600"
        >
          Test Cron Scheduler
        </button>
        
        <button 
          onClick={() => renderComponent('versionHistory')}
          className="p-4 bg-yellow-500 text-white rounded hover:bg-yellow-600"
        >
          Test Version History
        </button>
        
        <button 
          onClick={() => renderComponent('webhookManager')}
          className="p-4 bg-red-500 text-white rounded hover:bg-red-600"
        >
          Test Webhook Manager
        </button>
        
        <button 
          onClick={() => renderComponent('nodeTester')}
          className="p-4 bg-indigo-500 text-white rounded hover:bg-indigo-600"
        >
          Test Node Tester
        </button>
      </div>
      
      <div className="border p-4 rounded-lg shadow-md mb-8">
        <h2 className="text-xl font-semibold mb-4">WorkflowEditorActions Component</h2>
        <WorkflowEditorActions 
          workflowId={mockWorkflowId}
          selectedNode={mockSelectedNode}
          onDuplicateNode={(node) => console.log('Duplicate node:', node)}
          onDeleteNode={(node) => console.log('Delete node:', node)}
          onExecuteWorkflow={(id) => console.log('Execute workflow:', id)}
        />
      </div>
      
      <div className="border p-4 rounded-lg shadow-md">
        <h2 className="text-xl font-semibold mb-4">WorkflowEditorTabs Component</h2>
        <WorkflowEditorTabs 
          workflowId={mockWorkflowId}
          nodes={mockNodes}
          currentVersion={1}
          onRestoreVersion={(version) => console.log('Restore version:', version)}
        />
      </div>
      
      <Modal
        isOpen={showModal}
        onClose={() => setShowModal(false)}
        size="lg"
        title={activeComponent ? activeComponent.charAt(0).toUpperCase() + activeComponent.slice(1) : ''}
      >
        {activeComponent === 'executionResults' && (
          <ExecutionResults
            workflowId={mockWorkflowId}
            executionId={mockExecutionId}
            onClose={() => setShowModal(false)}
          />
        )}
        
        {activeComponent === 'executionHistory' && (
          <ExecutionHistory
            workflowId={mockWorkflowId}
          />
        )}
        
        {activeComponent === 'cronScheduler' && (
          <CronScheduler
            workflowId={mockWorkflowId}
          />
        )}
        
        {activeComponent === 'versionHistory' && (
          <VersionHistory
            workflowId={mockWorkflowId}
            currentVersion={1}
            onRestoreVersion={(version) => console.log('Restore version:', version)}
          />
        )}
        
        {activeComponent === 'webhookManager' && (
          <WebhookManager
            workflowId={mockWorkflowId}
            nodes={mockNodes}
          />
        )}
        
        {activeComponent === 'nodeTester' && (
          <NodeTester
            node={mockSelectedNode}
            onClose={() => setShowModal(false)}
          />
        )}
      </Modal>
    </div>
  );
};

export default TestComponents;
